# Potential v1 changes

Django Ninja is already used by tens of companies and by the visitors and downloads stats it's growing.

At this point introducing changes that will force current users to change their code (or break it) is not 
acceptable.

On the other hand some decisions that where initially made does not work well. These  breaking changes will be 
introduced in version 1.0.0

## Changes that most likely be in v1

 - **auth** will be class interface instead of callable (to support async authenticators)
 - **responses** to support **codes/headers/content** (like general Response class)
 - **routers paths** currently automatically **joined with "/"** - which might not needed on some cases where router prefix will act like a prefix and not subfolder

## Your thoughts/proposals

Please give you thoughts/likes/dislikes in the [github issue](https://github.com/vitalik/django-ninja/issues/146).

